# About

OpenRV is a open source wrapper for such computer vision libs as OpenCV, SciKit and imutils. The main idea of the project is to join lots of frequently used functions and utils under the complex classes to make the developing process easier and faster. 

So, according to the conception of this project feel free to request for a function/feature that you think can be useful for developing.

## Installation
Python 3.x is required.

Using pip:
``` shell
$ python3 -m pip install openrv
```

From source:
1) Download this repo
2) `$ python3 setup.py install`

Import: 
```python
from openrv import *
```

## Basics

 The library contains three(for now) classes: `Image`, `Contour`, `Contours`.
